# frozen_string_literal: true

# WARNING ABOUT GENERATED CODE
#
# This file is generated. See the contributing guide for more information:
# https://github.com/aws/aws-sdk-ruby/blob/version-3/CONTRIBUTING.md
#
# WARNING ABOUT GENERATED CODE


module Aws::ManagedBlockchainQuery
  module Plugins
    class Endpoints < Seahorse::Client::Plugin
      option(
        :endpoint_provider,
        doc_type: 'Aws::ManagedBlockchainQuery::EndpointProvider',
        rbs_type: 'untyped',
        docstring: 'The endpoint provider used to resolve endpoints. Any '\
                   'object that responds to `#resolve_endpoint(parameters)` '\
                   'where `parameters` is a Struct similar to '\
                   '`Aws::ManagedBlockchainQuery::EndpointParameters`'
      ) do |cfg|
        Aws::ManagedBlockchainQuery::EndpointProvider.new
      end

      # @api private
      class Handler < Seahorse::Client::Handler
        def call(context)
          unless context[:discovered_endpoint]
            params = parameters_for_operation(context)
            endpoint = context.config.endpoint_provider.resolve_endpoint(params)

            context.http_request.endpoint = endpoint.url
            apply_endpoint_headers(context, endpoint.headers)

            context[:endpoint_params] = params
            context[:endpoint_properties] = endpoint.properties
          end

          context[:auth_scheme] =
            Aws::Endpoints.resolve_auth_scheme(context, endpoint)

          @handler.call(context)
        end

        private

        def apply_endpoint_headers(context, headers)
          headers.each do |key, values|
            value = values
              .compact
              .map { |s| Seahorse::Util.escape_header_list_string(s.to_s) }
              .join(',')

            context.http_request.headers[key] = value
          end
        end

        def parameters_for_operation(context)
          case context.operation_name
          when :batch_get_token_balance
            Aws::ManagedBlockchainQuery::Endpoints::BatchGetTokenBalance.build(context)
          when :get_asset_contract
            Aws::ManagedBlockchainQuery::Endpoints::GetAssetContract.build(context)
          when :get_token_balance
            Aws::ManagedBlockchainQuery::Endpoints::GetTokenBalance.build(context)
          when :get_transaction
            Aws::ManagedBlockchainQuery::Endpoints::GetTransaction.build(context)
          when :list_asset_contracts
            Aws::ManagedBlockchainQuery::Endpoints::ListAssetContracts.build(context)
          when :list_filtered_transaction_events
            Aws::ManagedBlockchainQuery::Endpoints::ListFilteredTransactionEvents.build(context)
          when :list_token_balances
            Aws::ManagedBlockchainQuery::Endpoints::ListTokenBalances.build(context)
          when :list_transaction_events
            Aws::ManagedBlockchainQuery::Endpoints::ListTransactionEvents.build(context)
          when :list_transactions
            Aws::ManagedBlockchainQuery::Endpoints::ListTransactions.build(context)
          end
        end
      end

      def add_handlers(handlers, _config)
        handlers.add(Handler, step: :build, priority: 75)
      end
    end
  end
end
